@@ -1,7 +1,7 @@
 
-__version__ = '0.18.0'
+__version__ = '0.19.0'
 
 from poker.card import Suit, Rank, Card, FACE_RANKS, BROADWAY_RANKS
 from poker.hand import Shape, Hand, Combo, Range, PAIR_HANDS, OFFSUIT_HANDS, SUITED_HANDS
-from poker.constants import PokerRoom, Currency, Game, GameType, Limit, MoneyType, Action
+from poker.constants import PokerRoom, Currency, Game, GameType, Limit, MoneyType, Action, Position
 from poker.strategy import Strategy
